const fs = require('fs')

const changelogContent = fs.readFileSync('CHANGELOG.md', 'utf-8')
const lines = changelogContent.split('\n')

const h3Regex = /^###\s+(.*)$/
const h2Regex = /^##\s+(.*)$/

let allH3sCompliant = true
let currentH2 = null

for (let lineNumber = 0; lineNumber < lines.length; lineNumber++) {
  const line = lines[lineNumber]

  // Check for h3 heading
  const h3Match = line.match(h3Regex)
  if (h3Match) {
    const h3Heading = h3Match[1]

    // Check if h3 is under a valid h2
    if (currentH2 === null || !(currentH2.startsWith('v') || currentH2 === 'Unreleased')) {
      allH3sCompliant = false
      console.error(
        `h3 heading "${h3Heading}" on line ${lineNumber + 1} is not under a valid h2 (version or Unreleased)`,
      )
    }

    continue
  }

  // Check for h2 heading
  const h2Match = line.match(h2Regex)
  if (h2Match) {
    currentH2 = h2Match[1]
  }
}

if (!allH3sCompliant) {
  console.error('Some h3 headings are not placed under valid h2 headings. Failing the workflow.')
  process.exit(1)
}

console.log('All h3 headings are correctly placed under h2 headings!')
