import { RowComponentTemplate } from './Row.stories.js'

/**
 * A table component.
 *
 * Should be built using `Row` template/component.
 * */
export default {
  title: 'Components/Table/Table',
  tags: ['autodocs'],
  argTypes: {
    numColumns: {
      control: 'number',
      description: 'Number of columns in the table.',
    },
    numRows: {
      control: 'number',
      description: 'Number of rows in the table.',
    },
    sortHeaders: {
      control: 'boolean',
      description: 'Set to true to show the sorting arrows in header.',
    },
    includeButton: {
      control: 'boolean',
      description: 'Set to true to include a(n icon-only) button in the last column in the table',
    },
    includeTag: {
      control: 'boolean',
      description: 'Set to true to include a tag in the table',
    },
    maxHeight: {
      control: 'number',
      description:
        'Set the maximum height of the table (in px). If the table exceeds this height, it will be scrollable.',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    numColumns: 4,
    numRows: 4,
    sortHeaders: true,
    includeButton: false,
    includeTag: false,
    maxHeight: 0,
    fullWidth: false,
  },
}

const Template = (args) => {
  const maxHeightStyle = args.maxHeight ? `max-height: ${args.maxHeight / 16}rem;` : '';

  return `
    <div class='rpf-table ${args.fullWidth ? 'rpf-table--full-width' : ''}' style="${maxHeightStyle}">
      <table class='rpf-table__table  ${args.fullWidth ? 'rpf-table__table--full-width' : ''}'>
        <thead class='rpf-table__head'>
            ${RowComponentTemplate({ ...args, rowType: 'header' })}
        </thead>
        <tbody class='rpf-table-head'>
            ${Array.from({ length: args.numRows }, () => RowComponentTemplate({ ...args, rowType: 'body', tagColumn: args.numColumns - 2 })).join('')}
        </tbody>
      </table>
    </div>`
}

export const Table = Template.bind({})
Table.args = {
  numColumns: 4,
  numRows: 4,
  sortHeaders: true,
  includeButton: true,
  includeTag: true,
  maxHeight: 0,
  fullWidth: false,
}
